@@ -6,7 +6,7 @@ use 5.010;
 use Log::Log4perl qw( :easy );
 
 # ABSTRACT: Route builder for Clustericious applications
-our $VERSION = '0.9942'; # VERSION
+our $VERSION = '0.9943'; # VERSION
 
 
 our %Routes;
@@ -123,7 +123,7 @@ sub _add_routes {
              my $realm = $pattern || ref $app;
              my $cb = defined $auth_plugin ? sub { $auth_plugin->authenticate(shift, $realm) } : sub { 1 };
              $head_route = $head_authenticated = $routes =
-             $app->routes->bridge->to( { cb => $cb } )->name("authenticated");
+             $app->routes->under->to( { cb => $cb } )->name("authenticated");
              next;
          }
 
@@ -134,7 +134,7 @@ sub _add_routes {
             my $resource = $name;
             if($auth_plugin)
             {
-                $head_route = $routes = $head_authenticated->bridge->to( {
+                $head_route = $routes = $head_authenticated->under->to( {
                         cb => sub {
                             my $c = shift;
                             # Dynamically compute resource/action
@@ -148,7 +148,7 @@ sub _add_routes {
             }
             else
             {
-                $head_route = $routes = $head_authenticated->bridge->to({ cb => sub { 1 } });
+                $head_route = $routes = $head_authenticated->under->to({ cb => sub { 1 } });
             }
             next;
          }
@@ -156,7 +156,7 @@ sub _add_routes {
          # ladders don't replace previous ladders
          if (!ref $methods && $methods eq 'ladder') {
               die "constraints not handled in ladders" if $constraints && @$constraints;
-              $routes = $routes->bridge( $pattern )->over($conditions)
+              $routes = $routes->under( $pattern )->over($conditions)
                   ->to($defaults)->name($name);
               next;
          }
@@ -187,7 +187,7 @@ Clustericious::RouteBuilder - Route builder for Clustericious applications
 
 =head1 VERSION
 
-version 0.9942
+version 0.9943
 
 =head1 SYNOPSIS
 
