@@ -38,7 +38,7 @@ sub _init
 BEGIN { _init() }
 
 # ABSTRACT: Test Clustericious::Config
-our $VERSION = '0.9942'; # VERSION
+our $VERSION = '0.9943'; # VERSION
 
 
 sub create_config_ok ($;$$)
@@ -50,10 +50,9 @@ sub create_config_ok ($;$$)
   
   unless(defined $config)
   {
-    my $loader = Mojo::Loader->new;
     my $caller = caller;
-    $loader->load($caller);
-    $config = $loader->data($caller, "etc/$fn");
+    Mojo::Loader::load_class($caller);
+    $config = Mojo::Loader::data_section($caller, "etc/$fn");
   }
   
   my $tb = __PACKAGE__->builder;  
@@ -156,7 +155,7 @@ Test::Clustericious::Config - Test Clustericious::Config
 
 =head1 VERSION
 
-version 0.9942
+version 0.9943
 
 =head1 SYNOPSIS
 
